@@ -11,24 +11,27 @@ from .request_headers import get_request_headers
 
 
 class ApiConnection:
-    def __init__(self, id_user: str, key_pass: str, sleep=0.5, auth_type_user=False):
+    def __init__(self, id_user: str = "", key_pass: str = "", token=None, sleep=0.5, auth_type_user=False):
         self.id_user: str = id_user
         self.key_pass: str = key_pass
         self.sleep: float = sleep
         self.auth_type_user: bool = auth_type_user
 
-        dc_auth_params = {}
-        if auth_type_user:
-            dc_auth_params["root"] = 1
+        if token:
+            self.token = token
+        else:
+            dc_auth_params = {}
+            if auth_type_user:
+                dc_auth_params["root"] = 1
 
-        response = requests.request(
-            url=get_api_endpoint(endpoint='session'),
-            method='post',
-            params=dc_auth_params,
-            auth=HTTPBasicAuth(id_user, key_pass)
-        )
-        response_json = json.loads(response.text)
-        self.token: str = response_json["token"]
+            response = requests.request(
+                url=get_api_endpoint(endpoint='session'),
+                method='post',
+                params=dc_auth_params,
+                auth=HTTPBasicAuth(id_user, key_pass)
+            )
+            response_json = json.loads(response.text)
+            self.token: str = response_json["token"]
 
     def dc_request(
             self, url: str, method: str,
