@@ -50,8 +50,6 @@ ENDPOINTS = {
                   "report_rows/{report_row_id}",
     "report_rows": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/reports/{report_id}/"
                    "report_rows",
-    "report_trend": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/reports/{report_id}/"
-                    "statistics/report_trend",
 
     # Downloads
     "crawl_downloads": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/downloads",
@@ -63,12 +61,19 @@ ENDPOINTS = {
     # Statistics
     "report_statistics": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/reports/{report_id}/"
                          "statistics",
-    "report_statistic": "/accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/reports/{report_id}/"
+    "report_statistic": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/reports/{report_id}/"
                         "statistics/{statistic_type}",
     "crawl_statistics": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/statistics",
     "crawl_statistic": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/statistics/{statistic_type}",
     "issue_statistics": "accounts/{account_id}/projects/{project_id}/issues/{issue_id}/statistics",
-    "issue_statistic": "accounts/{account_id}/projects/{project_id}/issues/{issue_id}/statistics/{statistic_type}"
+    "issue_statistic": "accounts/{account_id}/projects/{project_id}/issues/{issue_id}/statistics/{statistic_type}",
+
+    # Report templates
+    "report_templates": "report_templates",
+    "datasources": "datasources",
+    "datasource": "datasources/{datasource_code}",
+    "datasource_report_templates": "/datasources/{datasource_code}/report_templates",
+    "datasource_report_template": "/datasources/{datasource_code}/report_templates/{report_template_id}",
 }
 
 
