@@ -2,8 +2,6 @@
 Crawl
 =====
 """
-from __future__ import annotations
-
 from typing import Union, Optional, List
 
 from requests import Response
@@ -11,6 +9,7 @@ from requests import Response
 import deepcrawl
 from deepcrawl.downloads.download import DeepCrawlCrawlDownloads
 from deepcrawl.reports.report import DeepCrawlReport
+from deepcrawl.statistics.statistic import DeepCrawlCrawlStatistic
 from deepcrawl.utils import ImmutableAttributesMixin
 from deepcrawl.utils import safe_string_to_datetime
 
@@ -21,6 +20,7 @@ crawl_extra_fields = (
     'reports',
     'reports_changes',
     'downloads',
+    'statistics'
 )
 
 crawl_mutable_fields = crawl_extra_fields + (
@@ -86,6 +86,7 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         self.reports = []
         self.reports_changes = []
         self.downloads = []
+        self.statistics = []
 
         # attributes
         self.crawling_at = safe_string_to_datetime(crawl_data.get('crawling_at'))
@@ -233,11 +234,36 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         )
         return self.downloads
 
+    def load_statistics(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlCrawlStatistic]:
+        """Loads statistics into current instance
+
+        >>> self.load_statistics()
+        [URL Breakdown, Web Crawl Depth]
+        >>> self.statistics
+        [URL Breakdown, Web Crawl Depth]
+
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: list of statistics
+        :rtype: list
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        self.statistics = connection.get_crawl_statistics(
+            self.account_id, self.project_id, self.id, filters=filters, **kwargs
+        )
+        return self.statistics
+
     """
     CRAWL
     """
 
-    def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlCrawl:
+    def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> 'deepcrawl.crawls.DeepCrawlCrawl':
         """Refresh crawl instance
 
         >>> self.refresh()
@@ -254,7 +280,9 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
             setattr(self, key, getattr(crawl, key))
         return self
 
-    def update(self, crawl_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlCrawl:
+    def update(
+            self, crawl_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> 'deepcrawl.crawls.DeepCrawlCrawl':
         """Update crawl instance
 
         >>> self.update(crawl_data)
@@ -401,3 +429,55 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         if self.downloads and use_cache:
             return self.downloads
         return self.load_downloads(connection=connection, filters=filters, **kwargs)
+
+    """
+    CRAWL STATISTICS
+    """
+
+    def get_crawl_statistic(
+            self, statistic_type: str, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlCrawlStatistic:
+        """Get crawl statistic
+
+        >>> self.get_crawl_statistic('report_trend')
+        URL Breakdown
+
+        :param statistic_type: statistic type
+        :type statistic_type: str
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: Requested statistic
+        :rtype: DeepCrawlCrawlStatistic
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        return connection.get_crawl_statistic(
+            self.account_id, self.project_id, self.id, statistic_type
+        )
+
+    def get_crawl_statistics(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlCrawlStatistic]:
+        """Get report statistics
+
+        * use_cache=True > get_crawl_statistics will return cached statistics or will do a call to DeepCrawl if statistics attribute is empty.
+        * use_cache=False > get_crawl_statistics will call DeepCrawl api and will override statistics attribute.
+
+        >>> self.get_crawl_statistics()
+        [URL Breakdown, Web Crawl Depth]
+
+        :param use_cache:
+        :type use_cache: bool
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: List of statistics
+        :rtype: list
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        if self.statistics and use_cache:
+            return self.statistics
+        return self.load_statistics(connection=connection, filters=filters, **kwargs)
