@@ -18,7 +18,6 @@ extraction_immutable_fields = (
 
 )
 
-
 extraction_fields = extraction_mutable_fields + extraction_immutable_fields
 
 
@@ -30,7 +29,7 @@ class DeepCrawlExtraction(ImmutableAttributesMixin):
 
     mutable_attributes = extraction_mutable_fields
 
-    def __init__(self, extraction_data):
+    def __init__(self, extraction_data: dict):
         self.label = extraction_data.get('label')
         self.regex = extraction_data.get('regex')
         self.match_number_from = extraction_data.get('match_number_from')
@@ -41,7 +40,7 @@ class DeepCrawlExtraction(ImmutableAttributesMixin):
         super(DeepCrawlExtraction, self).__init__()
 
     @property
-    def to_dict_mutable_fields(self):
+    def to_dict_mutable_fields(self) -> dict:
         """
         :return: dictionary with the mutable fields
         :rtype: dict
@@ -49,7 +48,7 @@ class DeepCrawlExtraction(ImmutableAttributesMixin):
         return {x: getattr(self, x, None) for x in extraction_mutable_fields}
 
     @property
-    def to_dict_immutable_fields(self):
+    def to_dict_immutable_fields(self) -> dict:
         """
         :return: dictionary with the immutable fields
         :rtype: dict
